@@ -66,17 +66,19 @@ def print_status_table(cci_path, recipes, print_all, jobs):
             continue
 
         if s.recipe_version.unknown or s.upstream_version.unknown:
-            name_color = fg("red")
+            name_color = fg("dark_gray")
         elif s.update_possible():
             name_color = fg("dark_orange")
-        else:
+        elif s.up_to_date():
             name_color = fg("green")
+        else:
+            name_color = fg("red")
 
         pr = s.pr_opened()
         pr_text = "Yes" if pr else "No"
 
-        rv_color = fg("green") if not s.recipe_version.unknown else fg("red")
-        uv_color = fg("green") if not s.upstream_version.unknown else fg("red")
+        rv_color = fg("green") if not s.recipe_version.unknown else fg("dark_gray")
+        uv_color = fg("green") if not s.upstream_version.unknown else fg("dark_gray")
         pr_color = fg("green") if pr else fg("dark_orange")
 
         table_data.append(
@@ -98,24 +100,29 @@ def update_status_issue(cci_path, issue_url_list, jobs, dry_run):
     t0 = time.time()
     recipes = get_recipes_list(cci_path)
     status = get_status(cci_path, recipes, jobs)
-    updatable = [s for s in status if s.update_possible() and not s.deprecated]
+    status = [s for s in status if not s.deprecated]
+    updatable = [s for s in status if s.update_possible()]
+    inconsistent_version = [s for s in status if s.inconsistent_versioning()]
     duration = time.time() - t0
 
     date = datetime.datetime.now().strftime("%d/%m/%Y")
     text = "\n".join(
         [
+            "# Conan Center Bot",
+            "",
             f"* Date: {date}",
             f"* Parsed recipes: {len(recipes)}",
             f"* Updatable recipes: {len(updatable)}",
             f"* Duration: {duration:.1f}s",
             "",
-            "Keep in mind this list is auto-generated and the "
-            "updatability detection can be flawed.",
+            "This list is auto-generated by [Conan Center Bot](https://github.com/qchateau/conan-center-bot) "
+            "and the updatability detection or version parsing can be flawed. Any help improving "
+            "this tool is welcome !",
             "",
-            "You can use conan-center-bot at "
-            "https://github.com/qchateau/conan-center-bot "
-            "to automatically generate an update.",
+            "You can also use [Conan Center Bot](https://github.com/qchateau/conan-center-bot) "
+            "to automatically generate an update for a recipe.",
             "",
+            "### Updatable recipes" "",
             "|Name|Recipe version|New version|Upstream version|Pending PR|",
             "|----|--------------|-----------|----------------|----------|",
         ]
@@ -133,6 +140,28 @@ def update_status_issue(cci_path, issue_url_list, jobs, dry_run):
             )
             for s in sorted(updatable, key=lambda s: s.name)
         ]
+        + [
+            "",
+            "### Inconsistent recipes",
+            "",
+            "The following recipes are not consistent with their upstream versioning scheme."
+            "Most of the times it means the current recipe version is not related to any upstream tag.",
+            "",
+            "|Name|Current recipe version|Upstream version|",
+            "|----|----------------------|----------------|",
+        ]
+        + [
+            "|".join(
+                [
+                    "",
+                    f"[{s.name}]({s.homepage})" if s.homepage else f"{s.name}",
+                    f"{s.recipe_version}",
+                    f"{s.upstream_version}",
+                    "",
+                ]
+            )
+            for s in sorted(inconsistent_version, key=lambda s: s.name)
+        ]
     )
 
     print(text)
